//[mahjong-utils](../../../index.md)/[mahjongutils.hora](../index.md)/[HoraOptions](index.md)/[hasComplexYakuman](has-complex-yakuman.md)

# hasComplexYakuman

[common]\
val [hasComplexYakuman](has-complex-yakuman.md): [Boolean](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-boolean/index.html)

是否有复合役满
